import QtQuick 2.0
import QtQuick.LocalStorage 2.0

Item{
    id: settingsmanager

    property bool initialized : false
    property bool aiplayer : true
    property string difficulty : "EASY"

    property int payoffEasy: 500
    property int payoffMedium: 1000
    property int payoffHard: 5000
    property int payoffInsane: 10000

    function getDatabase(){
        return LocalStorage.openDatabaseSync("Checkers", "1.0", "StorageDatabase", 1000000);
    }

    function getDifficultyPlayoff(){
        switch(difficulty){
        case "EASY": return payoffEasy
        case "MEDIUM": return payoffMedium
        case "HARD": return payoffHard
        case "INSANE": return payoffInsane
        }
    }

    //Get the flag on touch setting
    function getAIPlayer(){
        if(!initialized) init();
        return aiplayer;
    }

    //Get the last difficulty set
    function getDifficulty(){
        if(!initialized) init();
        return difficulty;
    }

    //Set the flag on touch setting
    function setAIPlayer(flag){
        if(!initialized) init();
        if(flag){
            aiplayer = true;
            setSetting("AI_PLAYER", "true");
        } else {
            aiplayer = false;
            setSetting("AI_PLAYER", "false");
        }
    }

    //Set the new difficulty
    function setDifficulty(diffString){
        if(!initialized) init();
        difficulty = diffString;
        setSetting("DIFFICULTY", diffString);
    }

    //Set a general setting string in the database
    function setSetting(setting, value){
        var db = getDatabase();
        var res = "";
        db.transaction(function(tx) {
            var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [setting,value]);

            if (rs.rowsAffected > 0) {
                res = "OK";
            } else {
                res = "Error";
            }
        }
        );
        // The function returns “OK” if it was successful, or “Error” if it wasn't
        return res;
    }

    //Retrieve a general setting string from the database
    function getSetting(setting) {
        var db = getDatabase();
        var res="";

        db.transaction(function(tx) {
            var rs = tx.executeSql('SELECT value FROM settings WHERE setting=?;', [setting]);
            if (rs.rows.length > 0) {
                res = rs.rows.item(0).value;
            } else {
                res = "";
            }
        });

        // The function returns “” if the setting was not found in the database
        // For more advanced projects, this should probably be handled through error codes
        return res
    }

    //Init the db, get the settings from db (if available)
    function init(){
        var db = getDatabase();
        db.transaction(
            function(tx) {
                tx.executeSql('CREATE TABLE IF NOT EXISTS settings(setting TEXT UNIQUE, value TEXT)');
            });

        var aiplayersetting = getSetting("AI_PLAYER");
        if(aiplayersetting === "false") aiplayer = false;
        else if(aiplayersetting === "true") aiplayer = true;

        var difficultySetting = getSetting("DIFFICULTY");
        if(difficultySetting === "") difficulty = "EASY";
        else difficulty = difficultySetting;

        initialized = true;
    }
}
