import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1

import "board.js" as Board
import "uct.js" as UCT
import "Constants.js" as Constants

MainView {
    objectName: "mainView"
    applicationName: "checkers"
    automaticOrientation: true
    
    width: units.gu(100)
    height: units.gu(75)

    //Non UI components//////////////////////////////////////////
    SettingsManager{
        id: settingsmanager
    }

    AITimer{
        id: aitimer
    }


    //UI components
    Tabs {
        id: tabs

        Tab {
            objectName: "Tab1"
            
            title: i18n.tr("Checkers")

            page: Page {
                MouseArea{
                    id: mousearea
                    anchors.fill: parent

                    onClicked: checkboardui.handleClick(mouse.x, mouse.y);

                    GameGrid{
                        id:checkboardui
                    }
                }

                tools: ToolbarActions {
                    Action {
                        objectName: "action"

                        iconSource: Qt.resolvedUrl("toolbarIcon.png")
                        text: i18n.tr("New Game")

                        onTriggered: {
                            var game = new Board.Checkers.Game(checkboardui);
                            game.start();
                        }
                    }
                }
            }

        }
        
        //Settings tab
        Tab {
            objectName: "Tab2"
            
            title: i18n.tr("Settings")
            page: Page {
                Column {
                    anchors.fill: parent

                    ListView{
                        id: settingslist
                        width: parent.width

                        ListItem.Standard{
                            id: aiplayersettingid
                            text: i18n.tr("AI Player")

                            control: Switch{
                                id: aiswitch
                                anchors.verticalCenter: parent.verticalCenter

                                onCheckedChanged: {
                                    if(checked){
                                        settingsmanager.setAIPlayer(true);
                                        difficultyselector.enabled = true;
                                    } else {
                                        settingsmanager.setAIPlayer(false);
                                        difficultyselector.enabled = false;
                                    }
                                }
                            }


                            Component.onCompleted: {
                                var ai = settingsmanager.getAIPlayer();
                                if(ai) aiswitch.checked = true;
                                else aiswitch.checked = false;
                            }
                        }

                        ListItem.ValueSelector {
                            id: difficultyselector
                            width: parent.width
                            anchors.top: aiplayersettingid.bottom
                            text: i18n.tr("Difficulty")
                            values: [i18n.tr("Easy"), i18n.tr("Medium"), i18n.tr("Hard"), i18n.tr("Insane")]
                            onSelectedIndexChanged: {
                                var diffSelected = "";
                                switch(selectedIndex){
                                case 0: diffSelected = "EASY"
                                    break;
                                case 1: diffSelected = "MEDIUM";
                                    break;
                                case 2: diffSelected = "HARD";
                                    break;
                                case 3: diffSelected = "INSANE";
                                    break;
                                }
                                settingsmanager.setDifficulty(diffSelected);
                            }

                            Component.onCompleted: {
                                selectedIndex =
                                        ["EASY", "MEDIUM", "HARD", "INSANE"].indexOf(settingsmanager.getDifficulty());
                                if(settingsmanager.getAIPlayer() === false) enabled = false;
                            }
                        }
                    }
                }
            }
        }
    }
}
